### Name: fitCopula
### Title: Estimation of the dependence parameters in copula models
### Aliases: fitCopula loglikCopula
### Keywords: models multivariate

### ** Examples

gumbel.cop <- gumbelCopula(3, dim=2)

n <- 200
x <- rcopula(gumbel.cop, n)       ## true observations
u <- apply(x, 2, rank) / (n + 1)  ## pseudo-observations
## inverting Kendall's tau
fit.tau <- fitCopula(u, gumbel.cop, method="itau")
fit.tau
## inverting Spearman's rho
fit.rho <- fitCopula(u, gumbel.cop, method="irho")
fit.rho
## maximum pseudo-likelihood
fit.mpl <- fitCopula(u, gumbel.cop, method="mpl")
fit.mpl
## maximum likelihood
fit.ml <- fitCopula(x, gumbel.cop, method="ml")
fit.ml

## a multiparameter example
normal.cop <- normalCopula(c(0.6,0.36, 0.6),dim=3,dispstr="un")
x <- rcopula(normal.cop, n)     ## true observations
u <- apply(x, 2, rank) / (n + 1)  ## pseudo-observations
## inverting Kendall's tau
fit.tau <- fitCopula(u, normal.cop, method="itau")
fit.tau
## inverting Spearman's rho
fit.rho <- fitCopula(u, normal.cop, method="irho")
fit.rho
## maximum pseudo-likelihood
fit.mpl <- fitCopula(u, normal.cop, method="mpl")
fit.mpl
## maximum likelihood
fit.ml <- fitCopula(x, normal.cop, method="ml")
fit.ml
## with dispstr="toep"
normal.cop.toep <- normalCopula(c(0, 0), dim=3, dispstr="toep")
## inverting Kendall's tau
fit.tau <- fitCopula(u, normal.cop.toep, method="itau")
fit.tau
## inverting Spearman's rho
fit.rho <- fitCopula(u, normal.cop.toep, method="irho")
fit.rho
## maximum pseudo-likelihood
fit.mpl <- fitCopula(u, normal.cop.toep, method="mpl")
fit.mpl
## maximum likelihood
fit.ml <- fitCopula(x, normal.cop.toep, method="ml")
fit.ml
## with dispstr="ar1"
normal.cop.ar1 <- normalCopula(c(0), dim=3, dispstr="ar1")
## inverting Kendall's tau
fit.tau <- fitCopula(u, normal.cop.ar1, method="itau")
fit.tau
## inverting Spearman's rho
fit.rho <- fitCopula(u, normal.cop.ar1, method="irho")
fit.rho
## maximum pseudo-likelihood
fit.mpl <- fitCopula(u, normal.cop.ar1, method="mpl")
fit.mpl
## maximum likelihood
fit.ml <- fitCopula(x, normal.cop.ar1, method="ml")
fit.ml

## a t copula with df.fixed=FALSE
t.cop <- tCopula(c(0.2,0.4,0.6),dim=3,dispstr="un",df=5)
x <- rcopula(t.cop, n)     ## true observations
u <- apply(x, 2, rank) / (n + 1)  ## pseudo-observations
## maximum likelihood
fit.ml <- fitCopula(x, t.cop, method="ml", start=c(0,0,0,10))
fit.ml
## maximum pseudo-likelihood; the asymptotic variance cannot be estimated 
fit.mpl <- fitCopula(u, t.cop, method="mpl", start=c(0,0,0,10),
                     estimate.variance=FALSE)
fit.mpl



